==> ejc-yanshi0521-impl-3.0.0-20230523.030643-3-sources.jar: com/ejianc/sxjg/vo/FeeCostVO.java <==
package com.ejianc.sxjg.vo;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.ejianc.framework.skeleton.template.BaseVO;

import com.ejianc.sxjg.vo.FeeCostSubVO;
import com.ejianc.sxjg.vo.FeeCostByjVO;

/**
 * 通用费用报销单
 * 
 * @author generator
 * 
 */
public class FeeCostVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private String code; // 单据编号
    private String name; // 单据名称
    private Integer billState; // 单据状态：0 自由态，1 已提交，2审批中，3 审批通过，4 驳回，5 提交后有人审批中
    private Long personId; // 报销人
    private Long orgid; // 报销组织
    private String workNum; // 工号
    private BigDecimal costMny; // 报销金额
    private String feeType; // 费用类别
    
    private List<FeeCostSubVO> feeCostSubList = new ArrayList<>(); // 费用信息
    private List<FeeCostByjVO> feeCostByjList = new ArrayList<>(); // 备用金

    public String getCode() {
        return code;
    }

    public void setCode(String code) {
        this.code = code;
    }
    public String getName() {
        return name;
    }

    public void setName(String name) {
        this.name = name;
    }
    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    public Long getPersonId() {
        return personId;
    }

    public void setPersonId(Long personId) {
        this.personId = personId;
    }
    public Long getOrgid() {
        return orgid;
    }

    public void setOrgid(Long orgid) {
        this.orgid = orgid;
    }
    public String getWorkNum() {
        return workNum;
    }

    public void setWorkNum(String workNum) {
        this.workNum = workNum;
    }
    public BigDecimal getCostMny() {
        return costMny;
    }

    public void setCostMny(BigDecimal costMny) {
        this.costMny = costMny;
    }
    public String getFeeType() {
        return feeType;
    }

    public void setFeeType(String feeType) {
        this.feeType = feeType;
    }
    
     public List<FeeCostSubVO> getFeeCostSubList() {
        return feeCostSubList;
     }

     public void setFeeCostSubList(List<FeeCostSubVO> feeCostSubList) {
        this.feeCostSubList = feeCostSubList;
     }
     public List<FeeCostByjVO> getFeeCostByjList() {
        return feeCostByjList;
     }

     public void setFeeCostByjList(List<FeeCostByjVO> feeCostByjList) {
        this.feeCostByjList = feeCostByjList;
     }
}

==> ejc-yanshi0521-impl-3.0.0-20230523.035304-4-sources.jar: com/ejianc/sxjg/vo/FeeCostVO.java <==
package com.ejianc.sxjg.vo;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.ejianc.framework.skeleton.refer.annotation.ReferDeserialTransfer;
import com.ejianc.framework.skeleton.refer.annotation.ReferSerialTransfer;
import com.ejianc.framework.skeleton.template.BaseVO;

import com.ejianc.sxjg.vo.FeeCostSubVO;
import com.ejianc.sxjg.vo.FeeCostByjVO;

/**
 * 通用费用报销单
 * 
 * @author generator
 * 
 */
public class FeeCostVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private String code; // 单据编号
    private String name; // 单据名称
    private Integer billState; // 单据状态：0 自由态，1 已提交，2审批中，3 审批通过，4 驳回，5 提交后有人审批中
    private Long personId; // 报销人
    private Long orgid; // 报销组织
    private String workNum; // 工号
    private BigDecimal costMny; // 报销金额
    private Long feeType; // 费用类别
    
    private List<FeeCostSubVO> feeCostSubList = new ArrayList<>(); // 费用信息
    private List<FeeCostByjVO> feeCostByjList = new ArrayList<>(); // 备用金

    public String getCode() {
        return code;
    }

    public void setCode(String code) {
        this.code = code;
    }
    public String getName() {
        return name;
    }

    public void setName(String name) {
        this.name = name;
    }
    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }

    @ReferSerialTransfer(referCode="idm-employee")
    public Long getPersonId() {
        return personId;
    }

    @ReferDeserialTransfer
    public void setPersonId(Long personId) {
        this.personId = personId;
    }
    @ReferSerialTransfer(referCode="idm-org")
    public Long getOrgid() {
        return orgid;
    }

    @ReferDeserialTransfer
    public void setOrgid(Long orgid) {
        this.orgid = orgid;
    }
    public String getWorkNum() {
        return workNum;
    }

    public void setWorkNum(String workNum) {
        this.workNum = workNum;
    }
    public BigDecimal getCostMny() {
        return costMny;
    }

    public void setCostMny(BigDecimal costMny) {
        this.costMny = costMny;
    }

    @ReferSerialTransfer(referCode="support-defdoc")
    public Long getFeeType() {
        return feeType;
    }

    @ReferDeserialTransfer
    public void setFeeType(Long feeType) {
        this.feeType = feeType;
    }
    
     public List<FeeCostSubVO> getFeeCostSubList() {
        return feeCostSubList;
     }

     public void setFeeCostSubList(List<FeeCostSubVO> feeCostSubList) {
        this.feeCostSubList = feeCostSubList;
     }
     public List<FeeCostByjVO> getFeeCostByjList() {
        return feeCostByjList;
     }

     public void setFeeCostByjList(List<FeeCostByjVO> feeCostByjList) {
        this.feeCostByjList = feeCostByjList;
     }
}
